@@ -2,17 +2,19 @@ import logging
 
 import rich_click as click
 
-from servicefoundry.build import lib
-from servicefoundry.build.console import console
-from servicefoundry.build.lib.messages import PROMPT_POST_LOGIN
+from servicefoundry.cli.console import console
+from servicefoundry.cli.const import COMMAND_CLS
+from servicefoundry.cli.io.rich_output_callback import RichOutputCallBack
 from servicefoundry.cli.util import handle_exception_wrapper
+from servicefoundry.lib import login
+from servicefoundry.lib.messages import PROMPT_POST_LOGIN
 
 logger = logging.getLogger(__name__)
 
 
-@click.command()
+@click.command(name="login", cls=COMMAND_CLS)
 @handle_exception_wrapper
-def login():
+def login_command():
     """
     Login to servicefoundry
 
@@ -23,9 +25,10 @@ def login():
     # TODO (chiragjn): Add support for non interactive login with API key.
     #                  It is supported indirectly as we always look for `SERVICE_FOUNDRY_API_KEY`
     #                  in the environment
-    lib.login(interactive=True)
+    callback = RichOutputCallBack()
+    login(interactive=True, output_hook=callback)
     console.print(PROMPT_POST_LOGIN)
 
 
 def get_login_command():
-    return login
+    return login_command
