@@ -2,13 +2,14 @@ import logging
 
 import rich_click as click
 
-from servicefoundry.build.lib import context as context_lib
+from servicefoundry.cli.const import COMMAND_CLS, GROUP_CLS
 from servicefoundry.cli.util import handle_exception_wrapper
+from servicefoundry.lib import context as context_lib
 
 logger = logging.getLogger(__name__)
 
 
-@click.group(name="use")
+@click.group(name="use", cls=GROUP_CLS)
 def use_command():
     """
     Set default workspace
@@ -21,7 +22,7 @@ def use_command():
     pass
 
 
-@click.command(name="cluster", help="Set default cluster")
+@click.command(name="cluster", cls=COMMAND_CLS, help="Set default cluster")
 @click.argument("cluster", type=click.STRING, required=False, default=None)
 @click.option("--non-interactive", is_flag=True, default=False)
 @handle_exception_wrapper
@@ -29,7 +30,7 @@ def use_cluster(cluster, non_interactive):
     context_lib.use_cluster(name_or_id=cluster, non_interactive=non_interactive)
 
 
-@click.command(name="workspace", help="Set default workspace")
+@click.command(name="workspace", cls=COMMAND_CLS, help="Set default workspace")
 @click.argument("workspace", type=click.STRING, required=False, default=None)
 @click.option("--non-interactive", is_flag=True, default=False)
 @handle_exception_wrapper
