@@ -1,7 +1,7 @@
 from fastapi import FastAPI
 
-from .metrics_router import metrics_router
-from .prometheus_middleware import PrometheusMiddleware
+from servicefoundry.service.fastapi.metrics_router import metrics_router
+from servicefoundry.service.fastapi.prometheus_middleware import PrometheusMiddleware
 
 
 def app():
